==> ozone-1.4.0-src.tar.gz: ozone-1.4.0-src/hadoop-ozone/interface-storage/src/test/java/org/apache/hadoop/ozone/om/helpers/TestS3SecretValueCodec.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.ozone.om.helpers;

import java.util.UUID;

import org.apache.hadoop.hdds.utils.db.Codec;
import org.apache.hadoop.hdds.utils.db.Proto2CodecTestBase;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * Test {@link S3SecretValue#getCodec()}.
 */
public class TestS3SecretValueCodec
    extends Proto2CodecTestBase<S3SecretValue> {
  @Override
  public Codec<S3SecretValue> getCodec() {
    return S3SecretValue.getCodec();
  }

  @Test
  public void testCodecWithCorrectData() throws Exception {
    final Codec<S3SecretValue> codec = getCodec();

    S3SecretValue s3SecretValue =
        new S3SecretValue(UUID.randomUUID().toString(),
            UUID.randomUUID().toString());

    byte[] data = codec.toPersistedFormat(s3SecretValue);
    Assertions.assertNotNull(data);

    S3SecretValue docdedS3Secret = codec.fromPersistedFormat(data);

    Assertions.assertEquals(s3SecretValue, docdedS3Secret);
  }
}

==> ozone-1.4.1-src.tar.gz: ozone-1.4.1-src/hadoop-ozone/interface-storage/src/test/java/org/apache/hadoop/ozone/om/helpers/TestS3SecretValueCodec.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.ozone.om.helpers;

import java.util.UUID;

import org.apache.hadoop.hdds.utils.db.Codec;
import org.apache.hadoop.hdds.utils.db.Proto2CodecTestBase;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 * Test {@link S3SecretValue#getCodec()}.
 */
public class TestS3SecretValueCodec
    extends Proto2CodecTestBase<S3SecretValue> {
  @Override
  public Codec<S3SecretValue> getCodec() {
    return S3SecretValue.getCodec();
  }

  @Test
  public void testCodecWithCorrectData() throws Exception {
    final Codec<S3SecretValue> codec = getCodec();

    S3SecretValue s3SecretValue =
        S3SecretValue.of(UUID.randomUUID().toString(),
            UUID.randomUUID().toString());

    byte[] data = codec.toPersistedFormat(s3SecretValue);
    Assertions.assertNotNull(data);

    S3SecretValue docdedS3Secret = codec.fromPersistedFormat(data);

    Assertions.assertEquals(s3SecretValue, docdedS3Secret);
  }
}
